import { Command } from './parser/parser.types';
declare enum ActionType {
    SET_WORKDIR = "SET_WORKDIR",
    START_PARSE = "START_PARSE",
    START_EXECUTE = "START_EXECUTE",
    EXECUTE_COMMAND = "EXECUTE_COMMAND",
    EXECUTE_JOB = "EXECUTE_JOB",
    EXECUTE_COMMANDS = "EXECUTE_COMMANDS"
}
export declare const setWorkdir: import("@reduxjs/toolkit").ActionCreatorWithPayload<{
    path: string;
}, ActionType.SET_WORKDIR>;
export declare const startParse: import("@reduxjs/toolkit").ActionCreatorWithPayload<{
    matronFilePath: string;
}, ActionType.START_PARSE>;
export declare const startExecute: import("@reduxjs/toolkit").ActionCreatorWithPayload<{
    commands: Command[];
}, ActionType.START_EXECUTE>;
export declare const executeCommand: import("@reduxjs/toolkit").ActionCreatorWithPayload<{
    commandItem: CommandItem;
}, ActionType.EXECUTE_COMMAND>;
export declare const executeJob: import("@reduxjs/toolkit").ActionCreatorWithPayload<{
    jobItem: JobItem;
}, ActionType.EXECUTE_JOB>;
declare type MatronActions = ReturnType<typeof setWorkdir> | ReturnType<typeof startParse> | ReturnType<typeof startExecute> | ReturnType<typeof executeCommand> | ReturnType<typeof executeJob>;
interface MatronOptions {
    executionPath?: string;
}
interface CommandItem {
    id: string;
    executed: boolean;
    rawCommand: Command;
    evaluatedCommand: Command;
}
export interface NormalizedState<T> {
    byId: Record<string, T>;
    allIds: string[];
}
interface JobItem {
    id: string;
    key: string;
    name?: string;
    commands: string[];
    executed: boolean;
}
interface MatronContext {
    config: {
        executionPath: string;
        matronFile: {
            path: string;
            text: string;
        };
    };
    jobs: NormalizedState<JobItem>;
    commands: NormalizedState<CommandItem>;
}
export declare function getStateMachineInterpreter(options: MatronOptions): import("xstate").Interpreter<MatronContext, any, MatronActions, {
    value: any;
    context: MatronContext;
}>;
export {};
